@@ -9,8 +9,8 @@ class BaseAppConfig(BaseSettings):
     config files, command line arguments and environment variables.
     """
 
-    backend: str = Field(
-        default="unsplash",
+    search_backends: tuple[str, ...] = Field(
+        default=("unsplash",),
         description="Image search backend to use for retrieving images.",
     )
 
